==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Alle lettertypen</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systeemlettertypen</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Mijn lettertypen</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorieten</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Ingeschakeld</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinees</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Vaste breedte</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bevestigen</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Beschadigd bestand</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Deze versie is al geïnstalleerd</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Systeemlettertype</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Lettertypen</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Er is %1 lettertype geïnstalleerd</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Er zijn %1 lettertypen geïnstalleerd</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Weet je zeker dat je dit lettertype wilt verwijderen?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Dit lettertype is niet beschikbaar in programma&apos;s</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Deze lettertypen zijn niet beschikbaar in programma&apos;s</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>De andere %1 systeemlettertypen kunnen niet worden verwijderd</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>&apos;%1&apos; is in gebruik en kan niet worden verwijderd</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>De andere %1 systeemlettertypen en het in gebruik zijnde lettertype &apos;%2&apos; kunnen niet worden verwijderd</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Weet je zeker dat je %1 lettertype(n) wilt verwijderen?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Bezig met verwijderen...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Lettertypeverificatie</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Doorgaan</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Er zijn geen te installeren lettertypen</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Laat je dromen uitkomen</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Bestandsinformatie</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stijl</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Volledige naam</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Postscriptnaam</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Merknaam</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Lettertypebeheer</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Met Lettertypebeheer kun je lettertypen installeren en beheren.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Bezig met laden van lettertypen...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Het lettertype is geëxporteerd</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>De %1 lettertypen zijn geëxporteerd</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>%1 lettertype kan niet worden geëxporteerd omdat er onvoldoende vrije schijfruimte is.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1 lettertypen kunnen niet worden geëxporteerd omdat er onvoldoende vrije schijfruimte is.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Lettertype toevoegen</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Uitschakelen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>uitgeschakeld</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>De lettertypen zijn uitgeschakeld</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 is in gebruik en kan daarom niet worden uitgeschakeld</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Je kunt in gebruik zijnde en systeemlettertypen niet uitschakelen</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Je kunt systeemlettertypen niet uitschakelen</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Enkele lettertypen mogen niet worden uitgeschakeld</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Lettertype installeren</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Bezig met verifiëren...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Beschadigd bestand</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Geïnstalleerd</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Niet geïnstalleerd</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Lettertype installeren</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Geen lettertypen</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pagina omhoog</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pagina omlaag</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Lettertype toevoegen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Eigenschappen</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Typ een voorbeeldzin</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Beschadigd bestand</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Alle lettertypen</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systeemlettertypen</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Mijn lettertypen</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorieten</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Ingeschakeld</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinees</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Vaste breedte</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 is een lettertypefamilie. Als je doorgaat, worden alle bijbehorende lettertypen verwijderd.</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 is een lettertypefamilie. Als je doorgaat, worden alle bijbehorende lettertypen ingeschakeld.</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 is een lettertypefamilie. Als je doorgaat, worden alle bijbehorende lettertypen uitgeschakeld.</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Uitschakelen</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Toepassen op alle geselecteerde lettertypefamilies</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Beschadigd bestand</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Deze versie is al geïnstalleerd</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Systeemlettertype</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Er is %1 lettertype geïnstalleerd</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Er zijn %1 lettertypen geïnstalleerd</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>%1 lettertype kan niet worden geïnstalleerd omdat er onvoldoende vrije schijfruimte is.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>%1 lettertypen kunnen niet worden geïnstalleerd omdat er onvoldoende vrije schijfruimte is.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Dit lettertype is niet beschikbaar in programma&apos;s</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Deze lettertypen zijn niet beschikbaar in programma&apos;s</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>De andere %1 systeemlettertypen kunnen niet worden verwijderd</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>&apos;%1&apos; is in gebruik en kan niet worden verwijderd</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>De andere %1 systeemlettertypen en het in gebruik zijnde lettertype &apos;%2&apos; kunnen niet worden verwijderd</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Weet je zeker dat je %1 lettertype(n) wilt verwijderen?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Bezig met verwijderen...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Lettertypeverificatie</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Er zijn geen te installeren lettertypen</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Doorgaan</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Bestandsinformatie</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stijl</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Volledige naam</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Postscriptnaam</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Merknaam</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Lettertypebeheer</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Met Lettertypebeheer kun je lettertypen installeren en beheren.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Bezig met laden van lettertypen...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Het lettertype is geëxporteerd</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>De %1 lettertypen zijn geëxporteerd</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>%1 lettertype kan niet worden geëxporteerd omdat er onvoldoende vrije schijfruimte is.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1 lettertypen kunnen niet worden geëxporteerd omdat er onvoldoende vrije schijfruimte is.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Lettertype toevoegen</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Uitschakelen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>uitgeschakeld</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>De lettertypen zijn uitgeschakeld</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 is in gebruik en kan daarom niet worden uitgeschakeld</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Je kunt in gebruik zijnde en systeemlettertypen niet uitschakelen</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Je kunt systeemlettertypen niet uitschakelen</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Lettertype installeren</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Bezig met verifiëren...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Beschadigd bestand</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Geïnstalleerd</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Niet geïnstalleerd</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Lettertype installeren</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Geen lettertypen</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pagina omhoog</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pagina omlaag</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Lettertype toevoegen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Eigenschappen</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Typ een voorbeeldzin</translation>
    </message>
</context>
</TS>
